[![Codacy Badge](https://app.codacy.com/project/badge/Grade/86f1594e0ac3406aa9609c4cd7c70642)](https://www.codacy.com/gh/princenyeche/atlassian-cloud-api/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=princenyeche/atlassian-cloud-api&amp;utm_campaign=Badge_Grade)
[![Downloads](https://pepy.tech/badge/jiraone)](https://pepy.tech/project/jiraone)
[![PyPI version](https://badge.fury.io/py/jiraone.svg)](https://badge.fury.io/py/jiraone)
![PyPI - License](https://img.shields.io/pypi/l/jiraone)

# Jira one
A REST API Implementation to Jira Cloud APIs for creating reports and for performing other Jira queries.

## Configurations
Install using `pip`. you have to be on python >= 3.6.x in order to utilize this script.
```bash
pip install jiraone
```

## Classes, functions and methods
Jiraone comes with various classes, functions and methods. Aliases as well, are used to represent
links to classes and functions. The major ones to take note of are the ones shown on the directory link below.

For further knowledge on how to use the classes, methods or functions. Open the jiraone package and read the docstring on the
aforementioned methods or functions above to get further information.

# Directory
* [Using the API](https://princenyeche.github.io/atlassian-cloud-api/api#using-the-api)
  * [endpoint](https://princenyeche.github.io/atlassian-cloud-api/api#endpoint)
  * [LOGIN](https://princenyeche.github.io/atlassian-cloud-api/api#login)
  * [echo](https://princenyeche.github.io/atlassian-cloud-api/api#echo)
  * [add_log](https://princenyeche.github.io/atlassian-cloud-api/api#add_log)
  * [file_writer](https://princenyeche.github.io/atlassian-cloud-api/api#file_writer)
  * [file_reader](https://princenyeche.github.io/atlassian-cloud-api/api#file_reader)
  * [path_builder](https://princenyeche.github.io/atlassian-cloud-api/api#path_builder)
  * [For](https://princenyeche.github.io/atlassian-cloud-api/api#for)
  * [replacement_placeholder](https://princenyeche.github.io/atlassian-cloud-api/api#replacement_placeholder)
  * [field](https://princenyeche.github.io/atlassian-cloud-api/api#field)
  * [comment](https://princenyeche.github.io/atlassian-cloud-api/api#comment)
* [Basic report usage](https://princenyeche.github.io/atlassian-cloud-api/report#basic-report-usage)
  * [PROJECT API](https://princenyeche.github.io/atlassian-cloud-api/report#project-api)
  * [USER API](https://princenyeche.github.io/atlassian-cloud-api/report#user-api)
  * [Support](https://princenyeche.github.io/atlassian-cloud-api/report#support)
